@@ -22,10 +22,17 @@ pub enum Message {
     Pause(PauseMessage),
     Kill(KillMessage),
 
+    /// Used to send some input to a process's stdin
     Send(SendMessage),
+
+    /// The first part of the three-step protocol to edit a task.
+    /// This one requests an edit from the daemon.
     EditRequest(usize),
+    /// The daemon locked the task and responds with the task's details.
     EditResponse(EditResponseMessage),
+    /// The client sends the edited details to the daemon.
     Edit(EditMessage),
+
     Group(GroupMessage),
     GroupResponse(GroupResponseMessage),
 
@@ -33,8 +40,12 @@ pub enum Message {
     StatusResponse(Box<State>),
     Log(LogRequestMessage),
     LogResponse(BTreeMap<usize, TaskLogMessage>),
-    Stream(String),
+
+    /// The client requests a continuous stream of a task's log.
     StreamRequest(StreamRequestMessage),
+    /// The next chunk of output, that's send to the client.
+    Stream(String),
+
     /// The boolean decides, whether the children should be get a SIGTERM as well.
     Reset(ResetMessage),
     Clean(CleanMessage),
@@ -46,6 +57,16 @@ pub enum Message {
     Parallel(ParallelMessage),
 }
 
+/// This enum is used to express a selection of tasks.
+/// As commands can be executed on various sets of tasks, we need some kind of datastructure to
+/// explicitly and unambiguously specify the selection.
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
+pub enum TaskSelection {
+    TaskIds(Vec<usize>),
+    Group(String),
+    All,
+}
+
 #[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct AddMessage {
     pub command: String,
@@ -72,34 +93,30 @@ pub struct EnqueueMessage {
     pub enqueue_at: Option<DateTime<Local>>,
 }
 
-#[derive(PartialEq, Clone, Debug, Default, Deserialize, Serialize)]
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct StartMessage {
-    pub task_ids: Vec<usize>,
-    pub group: String,
-    pub all: bool,
+    pub tasks: TaskSelection,
     pub children: bool,
 }
 
-#[derive(PartialEq, Clone, Debug, Default, Deserialize, Serialize)]
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct RestartMessage {
     pub tasks: Vec<TasksToRestart>,
     pub start_immediately: bool,
     pub stashed: bool,
 }
 
-#[derive(PartialEq, Clone, Debug, Default, Deserialize, Serialize)]
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct TasksToRestart {
     pub task_id: usize,
     pub command: String,
     pub path: String,
 }
 
-#[derive(PartialEq, Clone, Debug, Default, Deserialize, Serialize)]
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct PauseMessage {
-    pub task_ids: Vec<usize>,
-    pub group: String,
+    pub tasks: TaskSelection,
     pub wait: bool,
-    pub all: bool,
     pub children: bool,
 }
 
@@ -122,11 +139,9 @@ pub enum Signal {
     SigStop,
 }
 
-#[derive(PartialEq, Clone, Debug, Default, Deserialize, Serialize)]
+#[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
 pub struct KillMessage {
-    pub task_ids: Vec<usize>,
-    pub group: String,
-    pub all: bool,
+    pub tasks: TaskSelection,
     pub children: bool,
     pub signal: Option<Signal>,
 }
@@ -152,9 +167,10 @@ pub struct EditResponseMessage {
 }
 
 #[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
-pub struct GroupMessage {
-    pub add: Option<String>,
-    pub remove: Option<String>,
+pub enum GroupMessage {
+    Add(String),
+    Remove(String),
+    List,
 }
 
 #[derive(PartialEq, Clone, Debug, Deserialize, Serialize)]
